==> ministra-5.6.8.zip: stalker_portal/server/Lib/AdminAccess.php <==
<?php

namespace Ministra\Lib;

use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13;
class AdminAccess
{
    const ACCESS_VIEW = 'view';
    const ACCESS_CREATE = 'create';
    const ACCESS_DELETE = 'delete';
    const ACCESS_EDIT = 'edit';
    const ACCESS_PAGE_ACTION = 'page_action';
    const ACCESS_CONTEXT_ACTION = 'context_action';
    private $admin;
    public function __construct(\Ministra\Lib\Admin $admin)
    {
        $this->admin = $admin;
    }
    public static function convertPostParamsToAccessMap($post_data)
    {
        $fields = ['view', 'create', 'edit', 'delete', 'page_action', 'context_action'];
        $map = [];
        foreach ($fields as $field) {
            if (!isset($post_data[$field])) {
                continue;
            }
            foreach ($post_data[$field] as $page => $val) {
                if (!isset($map[$page])) {
                    $map[$page] = \array_fill_keys($fields, 0);
                    $map[$page]['page'] = $page;
                }
                $map[$page][$field] = $val;
            }
        }
        return \array_values($map);
    }
    public function check($page, $action = 'view')
    {
        if ($this->admin->getLogin() == 'admin') {
            return true;
        }
        return (bool) \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13::getInstance()->from('acl')->where(['gid' => $this->admin->getGID(), 'page' => $page, 'acl.' . $action => 1])->get()->first();
    }
}

==> ministra-5.6.10.zip: stalker_portal/server/Lib/AdminAccess.php <==
<?php

namespace Ministra\Lib;

use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7;
class AdminAccess
{
    const ACCESS_VIEW = 'view';
    const ACCESS_CREATE = 'create';
    const ACCESS_DELETE = 'delete';
    const ACCESS_EDIT = 'edit';
    const ACCESS_PAGE_ACTION = 'page_action';
    const ACCESS_CONTEXT_ACTION = 'context_action';
    private $admin;
    public function __construct(\Ministra\Lib\Admin $admin)
    {
        $this->admin = $admin;
    }
    public static function convertPostParamsToAccessMap($post_data)
    {
        $fields = ['view', 'create', 'edit', 'delete', 'page_action', 'context_action'];
        $map = [];
        foreach ($fields as $field) {
            if (!isset($post_data[$field])) {
                continue;
            }
            foreach ($post_data[$field] as $page => $val) {
                if (!isset($map[$page])) {
                    $map[$page] = \array_fill_keys($fields, 0);
                    $map[$page]['page'] = $page;
                }
                $map[$page][$field] = $val;
            }
        }
        return \array_values($map);
    }
    public function check($page, $action = 'view')
    {
        if ($this->admin->getLogin() == 'admin') {
            return true;
        }
        return (bool) \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7::getInstance()->from('acl')->where(['gid' => $this->admin->getGID(), 'page' => $page, 'acl.' . $action => 1])->get()->first();
    }
}
